@@ -1,7 +1,7 @@
 package aeos;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -59,7 +59,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 our $found_env;
 our $found_version;
@@ -301,6 +301,8 @@ sub ShowFlash {
         # persist changes constantly if you're running ntp, so
         # skip its updates.
         /\spersist$/ && next;
+	# frequent timestamp changes
+	/\sdebug$/ && next;
 
 	# Scheduled commands can cause free space to constantly
 	# change.  Even the trick of summarizing the free space
