@@ -1,7 +1,7 @@
 package arbor;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -54,7 +54,7 @@ use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -252,9 +252,15 @@ sub ShowHardware {
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	return(1) if (/invalid command/i);
 
+	# observed intermittently on T4008 running 9.2.0.
+	return(-1) if (/segmentation fault/i);
+
 	# observed intermittently on T4008 running 8.2.0.
 	return(-1) if (/error getting board version/i);
 
+	# observed intermittently on T4008 running 9.4.0.
+	return(-1) if (/error decoding result/i);
+
 	# some stupid timer error from this half-assed device
 	next if (/comsh: timer error, idle timeout will be unavailable/i);
 
