@@ -1,7 +1,7 @@
 package ciscowlc;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -56,7 +56,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -128,14 +128,16 @@ sub ShowConfig {
     ProcessHistory("","","","\n!--WLC Begin Config Data--!\n");
 
     while (<$INPUT>) {
-        tr/\015//d;
-        tr/\020//d;
+	tr/\001//d;				# filter garbage char
+	tr/\015//d;
+	tr/\020//d;
 	last if (/^$prompt/);
 
 	next if (/^\s*rogue ap classify/);
 	next if (/^\s*rogue (adhoc|client) (alert|unknown)/i);
 	next if (/^\s*interface nat-address management set -?[0-9]{4,}\./);
-
+	next if (/\x{7f}/);			# filter garbage line
+	
 	$linecnt++;
 
 	# These can not be imported, so comment them
@@ -147,7 +149,7 @@ sub ShowConfig {
 	    ProcessHistory("","","","!$_"); next;
 	}
 
-        # remove snmp community string data
+	# remove snmp community string data
 	if (/^(\s*snmp community create)/ && $filter_pwds >= 1) {
 	    ProcessHistory("","","","!$1 <removed>\n"); next;
 	}
