@@ -1,7 +1,7 @@
 package dnos10;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -174,8 +174,8 @@ REDO:	last if (/$prompt/);
 		/^\s*$/ && next;
 		if (/^(\d+\s+\w+\s+\w+\s+\w+\s+\d+\s+)(\d+)(\s+\w+)\s*$/) {
 		    my($sl) = length($2);
-                    my($fmt) = "%s%-". $sl ."s%s\n";
-                    $_ = sprintf($fmt, $1, "", $3);
+		    my($fmt) = "%s%-". $sl ."s%s\n";
+		    $_ = sprintf($fmt, $1, "", $3);
 		}
 		ProcessHistory("COMMENTS","keysort","C1","! $_");
 	    }
@@ -194,8 +194,8 @@ REDO:	last if (/$prompt/);
 		last if (/^-- /);		# next section
 		if (/^(\d+\s+\w+\s+\w+\s+\d+\s+)(\d+)(\s+\w+)\s*$/) {
 		    my($sl) = length($2);
-                    my($fmt) = "%s%-". $sl ."s%s\n";
-                    $_ = sprintf($fmt, $1, "", $3);
+		    my($fmt) = "%s%-". $sl ."s%s\n";
+		    $_ = sprintf($fmt, $1, "", $3);
 		} elsif (/^(\s+\d+\s+)(\d+)(\s+\w+)\s*$/) {
 		    my($sl) = length($2);
 		    my($fmt) = "%s%-". $sl ."s%s\n";
@@ -340,6 +340,24 @@ sub WriteTerm {
 	    next;
 	}
 
+	if (/^(username) (\S+)(\s.*)? password ((\d) \S+|\S+)/) {
+	    if ($filter_pwds >= 2) {
+		ProcessHistory("","","","!$1 $2 password <removed>\n");
+	    } else {
+		ProcessHistory("","","","$_");
+	    }
+	    next;
+	}
+
+	if (/^(system-user) (\S+)(\s.*)? password ((\d) \S+|\S+)/) {
+	    if ($filter_pwds >= 2) {
+		ProcessHistory("","","","!$1 $2 password <removed>\n");
+	    } else {
+		ProcessHistory("","","","$_");
+	    }
+	    next;
+	}
+
 	# order/prune snmp-server host statements
 	# we only prune lines of the form
 	# snmp-server host a.b.c.d <community>
@@ -361,9 +379,20 @@ sub WriteTerm {
 	    }
 	}
 
+	if (/^(snmp-server user) (\S+)(\s.*)?/) {
+	    if ($filter_commstr) {
+		ProcessHistory("SNMPSERVERCOMM","keysort","$2",
+			       "!$1 $2 <removed>\n");
+	    } else {
+		ProcessHistory("SNMPSERVERCOMM","keysort","$2","!$_");
+	    }
+	    next;
+	}
+
 	# prune tacacs/radius server keys
-	if (/^(tacacs-server|radius-server) key \w+/ && $filter_pwds >= 1) {
-	    ProcessHistory("","","","!$1 <removed>$'"); next;
+	if (/^((?:tacacs|radius)-server host) (\d+\.\d+\.\d+\.\d+) key 9 (\S+)/
+	    && $filter_pwds >= 1) {
+	    ProcessHistory("","","","!$1 $2 <removed>$'"); next;
 	}
 
 	ProcessHistory("","","","$_");
