@@ -1,7 +1,7 @@
 package edgerouter;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -81,8 +81,8 @@ sub inloop {
 TOP: while(<$INPUT>) {
 	tr/\015//d;
 	if (/^Error:/) {
-	    print STDOUT ("$host flogin error: $_");
-	    print STDERR ("$host flogin error: $_") if ($debug);
+	    print STDOUT ("$host $lscript error: $_");
+	    print STDERR ("$host $lscript error: $_") if ($debug);
 	    $clean_run = 0;
 	    last;
 	}
