@@ -1,7 +1,7 @@
 package exos;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -344,6 +344,11 @@ sub WriteTerm {
 	/# system name/i && next;
 	/# software version/i && next;
 
+	if (/((create|configure) account admin hivemanager) / && 
+	    ($filter_pwds >= 2 || $filter_osc >= 1)) {
+	    ProcessHistory("COMMENTS","keysort","H0","# $1 <key removed>\n");
+	    next;
+	}
 	if (/((create|configure) account \S+ \S+) / && $filter_pwds >= 2) {
 	    ProcessHistory("COMMENTS","keysort","H0","# $1 <key removed>\n");
 	    next;
