@@ -1,7 +1,7 @@
 package fss2;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -54,9 +54,9 @@ use strict 'vars';
 use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
-$Exporter::Verbose=1;
+#$Exporter::Verbose=1;
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #our @EXPORT = qw($VERSION)
