@@ -1,7 +1,7 @@
 package ios;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 our $proc;
 our $ios;
@@ -134,10 +134,6 @@ sub inloop {
 
 TOP: while(<$INPUT>) {
 	tr/\015//d;
-	if (/[>#]\s?exit$/) {
-	    $clean_run = 1;
-	    last;
-	}
 	if (/^Error:/) {
 	    print STDOUT ("$host clogin error: $_");
 	    print STDERR ("$host clogin error: $_") if ($debug);
@@ -170,6 +166,10 @@ TOP: while(<$INPUT>) {
 		last TOP;
 	    }
 	}
+	if (/[>#]\s?exit$/) {
+	    $clean_run = 1;
+	    last;
+	}
     }
 }
 
@@ -576,6 +576,7 @@ sub ShowDetail {
 	next if (/^\s+\^$/);
 	next if (/^Load for five/);
 	next if (/^Time source is/);
+	return(-1) if (/(?:%|command)? authorization failed/i);
 
 	next if (/^Load for five/);
 	next if (/^Time source is/);
@@ -602,7 +603,8 @@ sub ShowLicense {
 	next if (/^Time source is/);
 	return(0) if (/% no licensable udi in the system/i);	# show udi on old box
 	return(0) if (/% license not supported on this device/i);# show lic on old box
-	return(0) if (/% incomplete command/i);                 # show lic on old XE box
+	return(0) if (/% Ambiguous command/i);			# show lic featire on CSR1000v
+	return(0) if (/% incomplete command/i);			# show lic on old XE box
 	return(1) if (/Line has invalid autocommand /);
 	return(1) if (/(invalid (input|command) detected|type help or )/i);
 	return(-1) if (/(?:%|command)? authorization failed/i);
@@ -1093,7 +1095,7 @@ sub ShowFlash {
 	/\s+(private-multiple-fs|multiple-fs|LISP-MapCache-IPv\S+|nv_hdr)$/ &&
 	    next;
 
-	if (/(dhcp_[^. ]*\.txt|license_evlog|vlan\.dat|sflog|snooping)/ ||
+	if (/(dhcp_[^. ]*\.txt|license_evlog|\slog\s*$|vlan\.dat|sflog|snooping)/ ||
 		 /(LOCAL-CA-SERVER(?:[^\s]*))\s*$/ ||
 		 /(smart-log\/agentlog|syslog)\s*$/ ||
 		 /(log\/(?:ssp_tz\/)?[^. ]+\.log(?:\.[0-9]+\.gz)?)\s*$/) {
@@ -1269,8 +1271,9 @@ sub DirSlotN {
 	# to:
 	#       -rw-                                   vlan.dat
 	#       -rw-                                           vlan.dat
-	if (/(dhcp_[^. ]*\.txt|vlan\.dat|sflog|snooping|syslog)\s*$/ ||
-	    /(tracelogs|throughput_monitor_params|underlying-config)\s*$/) {
+	if (/(dhcp_[^. ]*\.txt|vlan\.dat|\slog|sflog|snooping|syslog)\s*$/ ||
+	    /(\sssd|tracelogs|throughput_monitor_params)\s*$/ ||
+	    /((?:private|startup|underlying)-config)\s*$/) {
 	    if (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/) {
 		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
 		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
@@ -1281,6 +1284,12 @@ sub DirSlotN {
 		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
 		my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s";
 		$_ = sprintf($fmt, $a, "", $c, "", $rem);
+	    } elsif (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+)(\d+:\d+:\d+ \w+ \d+\s+\d+)/) {
+		#  7      drwx  4096         16:43:28 Oct 08 2021  log
+		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
+		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
+		my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s";
+		$_ = sprintf($fmt, $a, "", $c, "", $rem);
 	    } elsif (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+<no date>)/i) {
 		# 32771  -rw-            24520                    <no date>  underlying-config
 		my($fn, $a, $sz, $dt, $rem) = ($1, $2, $3, $4, $');
@@ -2364,7 +2373,7 @@ TOP:
 	    s/^$1\s{$len}//;
 	}
 	/^! no configuration change since last restart/i && next;
-	# skip emtpy lines at the beginning
+	# skip empty lines at the beginning
 	if (!$linecnt && /^\s*$/) {
 	    next;
 	}
@@ -2620,12 +2629,12 @@ TOP:
 	    ProcessHistory("ACL $1 $2","$aclsort","$3","$_") && next;
 	# order extended access-lists
 	if ($aclfilterseq) {
-	/^access-list\s+(\d\d\d)\s+(\S+)\s+(\S+)\s+host\s+(\S+)/ &&
-	    ProcessHistory("EACL $1 $2","$aclsort","$4","$_") && next;
-	/^access-list\s+(\d\d\d)\s+(\S+)\s+(\S+)\s+(\d\S+)/ &&
-	    ProcessHistory("EACL $1 $2","$aclsort","$4","$_") && next;
-	/^access-list\s+(\d\d\d)\s+(\S+)\s+(\S+)\s+any/ &&
-	    ProcessHistory("EACL $1 $2","$aclsort","0.0.0.0","$_") && next;
+	    /^access-list\s+(\d\d\d)\s+(\S+)\s+(\S+)\s+host\s+(\S+)/ &&
+		ProcessHistory("EACL $1 $2","$aclsort","$4","$_") && next;
+	    /^access-list\s+(\d\d\d)\s+(\S+)\s+(\S+)\s+(\d\S+)/ &&
+		ProcessHistory("EACL $1 $2","$aclsort","$4","$_") && next;
+	    /^access-list\s+(\d\d\d)\s+(\S+)\s+(\S+)\s+any/ &&
+		ProcessHistory("EACL $1 $2","$aclsort","0.0.0.0","$_") && next;
 	}
 	if ($aclfilterseq) {
 	    /^ip(v6)? prefix-list\s+(\S+)\s+seq\s+(\d+)\s+(permit|deny)\s+(\S+)(.*)/
@@ -2634,13 +2643,27 @@ TOP:
 		&& next;
 	}
 	# sort ipv{4,6} access-lists
-	if ($aclfilterseq && /^ipv(4|6) access-list (\S+)\s*$/) {
+	if ($aclfilterseq && /^(ipv(?:4|6)|ip) access-list (?:extended |standard )?(\S+)\s*$/) {
 	    my($nlri, $key) = ($1, $2);
-	    my($seq, $cmd);
+	    my($seq, $cmd, $regexfilter);
 	    ProcessHistory("ACL $nlri $key","","","$_");
+	    # filter ACL contents
+	    $regexfilter = 0;
+	    if (defined($aclfilterregex) && length($aclfilterregex)) {
+		my($i);
+		my(@regexes) = split('\;', $aclfilterregex);
+		for ($i = 0; $i < ($#regexes + 1); $i++) {
+		    if ($key =~ /$regexes[$i]/) {
+			$regexfilter = 1;
+			ProcessHistory("ACL $nlri $key !", "", "",
+				       "! <$key contents removed by ACLFILTERREGEX>\n");
+		    }
+		}
+	    }
 	    while (<$INPUT>) {
 		tr/\015//d;
 		last if (/^$prompt/ || /^\S/);
+		next if ($regexfilter);
 		# ipv4 access-list name
 		#  remark NTP
    		#  deny ipv4 host 224.0.1.1 any
@@ -2795,4 +2818,18 @@ TOP:
     return(0);
 }
 
+# This routine processes a generic command, commenting all of its output
+sub RunCommandComment {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    print STDERR "    In RunCommandComment: $_" if ($debug);
+
+    while (<$INPUT>) {
+	tr/\015//d;
+	last if (/^$prompt/);
+	ProcessHistory("COMMENTS","keysort","_RCC","! $_");
+    }
+    ProcessHistory("COMMENTS","keysort","_RCC","!\n");
+    return(0);
+}
+
 1;
