@@ -1,7 +1,7 @@
 package iosxr;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 our $proc;
 our $found_env;
@@ -623,9 +623,11 @@ sub ShowEnv {
 		last if (/^altitude information/i);
 		last if (/^=+$/i && ($sep > 1));
 		$sep++ if (/^=+$/i);
-		if (/^(\s+\S+\s+\S+-(?:AC|DC)\s+)(\S+\s+\S+\s+\S+\s+\S+)(\s+.*)/) {
+		/^total of power shelf \d+:/i && next;
+		if (/^(\s+\S+\s+(?:\S+-(?:AC|DC)|-)\s+)(\S+\s+\S+\s+\S+\s+\S+)(\s+.*)/) {
 		    $_ = sprintf("%s%-". length($2) ."s%s\n", $1, "", $3);
 		}
+		s/\s+$/\n/;
 		ProcessHistory("COMMENTS","keysort","E1","!Power: $_");
 	    }
 	    next;
@@ -678,6 +680,9 @@ sub DirSlotN {
 	return(-1) if (/command authorization failed/i);
 	return(1) if (/(Open device \S+ failed|Error opening \S+:)/);
 
+	# CSCvu27946
+	next if (/drbg_instantiate failed/);
+
 	# Filter dhcp database
 	if (/dhcp_[^. ]*\.txt/) {
 	    next;
@@ -691,8 +696,9 @@ sub DirSlotN {
 	if ($dev =~ /(bootflash|disk[0-9]|harddisk|nvram)/) {
 	    if (/\s(\.python-history|aaa|\.bash_history|.sppdc)\s*$/ ||
 	        /\s(ce_switch.log\S*|cisco_support|errmsg_cont)\s*$/ ||
-	        /\s(genstr_cont|temp_cont|temp_cont|temp_static_data)\s*$/ ||
-	        /\s(uptime_cont|volt_cont|volt_hist)\s*$/) {
+	        /\s(feature_list|genstr_cont|nvgen_bkup\S*|temp_cont)\s*$/ ||
+	        /\s(temp_cont|temp_static_data|uptime_cont|volt_cont)\s*$/ ||
+	        /\s(volt_hist)\s*$/) {
 		# change
 		# 57          -rw-  23100       <no date>              volt_cont
 		# 614788      drwx  4096        Fri Aug 20 12:06:25 2010  temp_cont
@@ -1060,6 +1066,10 @@ sub ShowRPL {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^(\s*|\s*$cmd\s*)$/);
+
+	# CSCvu27946
+	next if (/drbg_instantiate failed/);
+
 	# filter the bloody cmd-line timestamp
 	next if (/^\w{3} \w{3,4} {1,3}\d{1,2} {1,2}\d{1,2}:\d+:\d+\.\d+ \S+$/);
 	return(1) if /^\s*\^\s*$/;
@@ -1067,6 +1077,7 @@ sub ShowRPL {
 	return(1) if (/(Invalid (input|command) detected|Type help or )/i);
 	return(1) if (/^(-+\^|syntax error: unknown argument)$/i);	# NCS
 	return(1) if (/Ambiguous command/i);
+	return(-1) if (/backing_thread:accept_file: .*/i);
 	return(-1) if (/command authorization failed/i);
 
 	ProcessHistory("COMMENTS","keysort","RPLMAX","! $_");
@@ -1118,6 +1129,7 @@ REPEAT:	tr/\015//d;
 	return(0) if ($found_end);		# Only do this routine once
 	return(-1) if (/command authorization failed/i);
 	return(-1) if (/% ?configuration buffer full/i);
+	return(-1) if (/^ *drbg_instantiate failed/i);			# xr7.1
 	/^! no configuration change since last restart/i && next;
 	# skip emtpy lines at the beginning
 	if (!$linecnt && /^\s*$/) {
@@ -1223,7 +1235,7 @@ REPEAT:	tr/\015//d;
 	if (/^(ppp .* password) 7 .*/ && $filter_pwds >= 1) {
 	    ProcessHistory("","","","!$1 <removed>\n"); next;
 	}
-	if (/^(ip ftp password) / && $filter_pwds >= 1) {
+	if (/^(ftp client password) / && $filter_pwds >= 1) {
 	    ProcessHistory("","","","!$1 <removed>\n"); next;
 	}
 	if (/^( ip ospf authentication-key) / && $filter_pwds >= 1) {
@@ -1319,21 +1331,24 @@ REPEAT:	tr/\015//d;
 	}
 	# filter out any RCS/CVS tags to avoid confusing local CVS storage
 	s/\$(Revision|Id):/ $1:/;
-	# order access-lists
-	/^access-list\s+(\d\d?)\s+(\S+)\s+(\S+)/ &&
-	    ProcessHistory("ACL $1 $2","$aclsort","$3","$_") && next;
-	# order extended access-lists
-	/^access-list\s+(\d\d\d)\s+(\S+)\s+ip\s+host\s+(\S+)/ &&
-	    ProcessHistory("EACL $1 $2","$aclsort","$3","$_") && next;
-	/^access-list\s+(\d\d\d)\s+(\S+)\s+ip\s+(\d\S+)/ &&
-	    ProcessHistory("EACL $1 $2","$aclsort","$3","$_") && next;
-	/^access-list\s+(\d\d\d)\s+(\S+)\s+ip\s+any/ &&
-	    ProcessHistory("EACL $1 $2","$aclsort","0.0.0.0","$_") && next;
 	# sort ipv{4,6} access-lists
 	if ($aclfilterseq && /^ipv(4|6) access-list (\S+)\s*$/) {
 	    my($nlri, $key) = ($1, $2);
-	    my($seq, $cmd);
+	    my($seq, $cmd, $regexfilter);
 	    ProcessHistory("ACL $nlri $key","","","$_");
+	    # filter ACL contents
+	    $regexfilter = 0;
+	    if (defined($aclfilterregex) && length($aclfilterregex)) {
+		my($i);
+		my(@regexes) = split('\;', $aclfilterregex);
+		for ($i = 0; $i < ($#regexes + 1); $i++) {
+		    if ($key =~ /$regexes[$i]/) {
+			$regexfilter = 1;
+			ProcessHistory("ACL $nlri $key !", "", "",
+				       "! <$key contents removed by ACLFILTERREGEX>\n");
+		    }
+		}
+	    }
 	    while (<$INPUT>) {
 		tr/\015//d;
 		goto REPEAT if (/^$prompt/ || !/^(\s|\d|!)/);
@@ -1341,6 +1356,7 @@ REPEAT:	tr/\015//d;
 		    ProcessHistory("ACL $nlri $key !", "", "", "$_");
 		    next;
 		}
+		next if ($regexfilter);
 		# ipv4 access-list name
 		#  remark NTP
    		#  deny ipv4 host 224.0.1.1 any
