@@ -1,7 +1,7 @@
 package junos;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -54,9 +54,9 @@ use strict 'vars';
 use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
-$Exporter::Verbose=1;
+#$Exporter::Verbose=1;
 
-use rancid 3.13;
+use rancid 3.14;
 
 our $ShowChassisSCB;			# Only run ShowChassisSCB() once
 our $ShowChassisFirmware;		# Only run ShowChassisFirmware() once
@@ -392,6 +392,23 @@ sub ShowChassisAlarms {
 	/^\s+\^/ && return(1);
 	/syntax error/ && return(1);
 
+	# filter timestamps, some oscillate
+	# 2021-11-15 06:10:09 NZDT Minor  IDP Signature usage requires a license
+	if (/^([0-9-]+ \d+:\d+:\d+ \w+) /) {
+	    my($len, $rem) = (length($1), $');
+	    my($fmt) = "%-". $len ."s %s";
+	    $_ = sprintf($fmt, "", $rem);
+	}
+
+	# filter FIB/RIB/LSP/BGP Peer Scale value, oscillates
+	# 2021-11-15 06:10:09 NZDT Minor  1049871 FIB Scales(268) require a license
+	# 2021-11-15 06:10:09 NZDT Minor  1063110 RIB Scales(269) require a license
+	# 2021-11-15 06:10:09 NZDT Minor  563 LSP Scales(270) require a license
+	# 2021-11-15 06:10:09 NZDT Minor  385 BGP Peer scales(271) require a license
+	if (/^(\s+\w+\s+)(\d+)( (?:fib|rib|lsp|bgp peer) scale.+ require a license)/i) {
+	    $_ = sprintf("%s%s%s%s", $1, "<removed>", $3, $');
+	}
+
 	ProcessHistory("","","","# $_");
     }
     return(0);
@@ -488,14 +505,33 @@ sub ShowSystemLicense {
 	return -1 if (/error: select: protocol failure /i);
 	return -1 if (/error: abnormal communication /i);
 
+	# licenses used/needed changes constantly for routing licenses.  Remove
+	# them.  example input:
+	# License usage:
+	#                                  Licenses     Licenses    Licenses    Expiry
+	#   Feature name                       used    installed      needed
+        #   fib-scale                       1049871        64000      985871    permanent
+        #   rib-scale                       1063110        64000      999110    permanent
+        #   lsp-scale                           563            0         563    invalid
+        #   bgp-peer-scale                      385            0         385    invalid
+	if (/^(\s+(?:fib|rib|lsp|bgp-peer)-\S+\s+)(\d+)(\s+\d+)(\s+\d+)(.*$)/) {
+	    my($a, $used, $avail, $need, $rem) = ($1, $2, $3, $4, $5);
+	    my($usedl, $needl) = (length($used), length($need));
+	    my($fmt) = "%s%-" . $usedl . "s%s%-" . $needl . "s%s\n";
+	    $_ = sprintf($fmt, $a, "", $avail, "", $rem);
+	}
+
 	# licenses used changes constantly.  distill it to a percentage.
 	# example input:
 	# License usage:
 	#                                  Licenses     Licenses    Licenses    Expiry
 	#   Feature name                       used    installed      needed
 	#   dynamic-vpn                           1            2           0    permanent
-	if (/^(\s+(?:VMX|dynamic|mobile|scale|service|scale-subscriber|subscriber)-\S+)(\s+)(\d+)(\s+\d+)(.*$)/) {
-	    my($a, $sp, $used, $avail, $rem) = ($1, $2, $3, $4, $5);
+	#   mx5-to-mx10-upgrade                   1            0           1    30 days
+	#   mx10-to-mx40-upgrade                  1            0           1    20 hours
+	#   mx40-to-mx80-upgrade                  1            0           1    10 minutes
+	if (/^(\s+(?:VMX|dynamic|mobile|scale|service|scale-subscriber|subscriber)-\S+)(\s+)(\d+)(\s+\d+)(\s+\d+)(.*$)/) {
+	    my($a, $sp, $used, $avail, $need, $rem) = ($1, $2, $3, $4, $5, $6);
 	    my($spl, $usedl) = (length($sp), length($used));
 	    my($pcnt, $usage, $usagel);
 	    if ($avail < 1) {
@@ -516,8 +552,17 @@ sub ShowSystemLicense {
 	    $usagel = length($usage) ;
 	    $spl = $spl + $usedl - $usagel;
 
-	    my($fmt) = "%s%-" . $spl . "s%s%s%s\n";
-	    $_ = sprintf($fmt, $a, "", $usage, $avail, $rem);
+	    if ($rem =~ /^(\s+)(.*)\s*$/) {
+		my($L) = $1;
+		my($T) = $2;
+		
+		if ($filter_osc >= 1 && $T !~ /permanent/i) {   
+		    $rem = "$L<limited>";
+		}
+	    }
+
+	    my($fmt) = "%s%-" . $spl . "s%s%s%s%s\n";
+	    $_ = sprintf($fmt, $a, "", $usage, $avail, $need, $rem);
 	}
 
 	/Unrecognized command/ && return(1);
@@ -597,6 +642,9 @@ sub ShowVersion {
 	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
 	/error: abnormal communication termination with / && return(-1);
 	/error: could not connect to \S+ ?: no route to host/i && return(1);
+	# this happens from time to time, esp. with PHONE-HOME, and resolves
+	# on the next run.  So, just retry.
+	/: Resource deadlock avoided/ && return(-1);
 
 	/warning: .* subsystem not running - not needed by configuration/ && next;
 
