@@ -1,7 +1,7 @@
 package nxos;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 our $proc;
 our $type;				# device model, from ShowVersion
@@ -117,6 +117,8 @@ TOP: while(<$INPUT>) {
 	    if (!defined($prompt)) {
 		$prompt = ($_ =~ /^([^#]+#)/)[0];
 		$prompt =~ s/([][}{)(\\])/\\$1/g;
+		# accept prompts like nexus on a ucs "routername(nexus)#"
+		$prompt =~ s/([#])$/(\\\([^)$1]+\\\))?\\$1/g;
 		print STDERR ("PROMPT MATCH: $prompt\n") if ($debug);
 	    }
 	    print STDERR ("HIT COMMAND:$_") if ($debug);
@@ -214,7 +216,18 @@ EndSoftware:
 	    }
 	}
 EndHardware:
-	if (/^\s+(bootflash|slot0):\s+(\d+) kB(.*)$/) {
+	if (/^\s+(bootflash):\s+(\d+) kB(.*)$/) {
+	    my($tmp) = int($2 / 1024);
+	    # CSCvz71586 accessing bootflash from multiple VDCs might return 0
+	    if ($2 == 0) {
+		print STDERR "ERROR: bootflash: size 0\n";
+		return(-1);
+	    }
+	    ProcessHistory("COMMENTS","keysort","B1",
+			   "!Memory: $1: $tmp MB$3\n");
+	    next;
+	}
+	if (/^\s+(slot0):\s+(\d+) kB(.*)$/) {
 	    my($tmp) = int($2 / 1024);
 	    ProcessHistory("COMMENTS","keysort","B1",
 			   "!Memory: $1: $tmp MB$3\n");
@@ -538,7 +551,7 @@ sub DirSlotN {
 
 	next if (/BufferMonitor-1HourData/);
 
-	if (/( debug_logs| log)\/$/) {
+	if (/( debug_logs| log| icamsql[^.]*\.db.*)\/$/) {
 	    # change
 	    #         8192    Jan 08 14:05:05 2015  log/
 	    # to
