@@ -1,7 +1,7 @@
 package panos;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -62,7 +62,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -142,8 +142,6 @@ TOP: while(<$INPUT>) {
 # This routine parses "show system info"
 sub ShowInfo {
     my($INPUT, $OUTPUT, $cmd) = @_;
-    my($slot);
-
     print STDERR "    In ShowInfo:: $_" if ($debug);
 
     while (<$INPUT>) {
@@ -151,6 +149,7 @@ sub ShowInfo {
 	last if (/^$prompt/);
 	next if (/^(time:|uptime:)/);
 	next if (/^(app|av|global-protect-datafile|threat|wf-private|wildfire|url-filtering)-(version|release-date):/);
+	s/\s+$/\n/;				# remove tailing whitespaces
 
 	ProcessHistory("INFO","","","#$_");
     }
@@ -161,14 +160,13 @@ sub ShowInfo {
 # This routine parses "show chassis inventory"
 sub ShowInventory {
     my($INPUT, $OUTPUT, $cmd) = @_;
-    my($slot);
-
     print STDERR "    In ShowInventory:: $_" if ($debug);
 
     while (<$INPUT>) {
 	tr/\015//d;
 	last if (/^$prompt/);
 	return(1) if (/^Invalid syntax/);
+	s/\s+$/\n/;				# remove tailing whitespaces
 
 	ProcessHistory("INV","","","#$_");
     }
