@@ -1,7 +1,7 @@
 package rancid;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -69,6 +69,7 @@ our $filter_commstr;			# SNMP community string filtering
 our $filter_osc;			# oscillating data filtering mode
 our $filter_pwds;			# password filtering mode
 our $aclsort;				# ACL sorting mode
+our $aclfilterregex;			# ACL filter regex
 our $aclfilterseq;			# ACL sequence filtering mode
 our $log;				# log cmdline option
 our $debug;				# debug cmdline option
@@ -89,9 +90,9 @@ our @EXPORT = qw($VERSION $devtype $script $lscript @modules $inloop
 		@commandtable
 		%commands @commands $commandcnt
 		$commandstr $cmds_regexp
-		$filter_commstr $filter_osc $filter_pwds $aclsort $aclfilterseq
-		$log $debug $file $host $clean_run $found_end $timeo $timeodef
-		$prompt
+		$filter_commstr $filter_osc $filter_pwds $aclsort
+		$aclfilterregex $aclfilterseq $log $debug $file $host
+		$clean_run $found_end $timeo $timeodef $prompt
 
 		bytes2human diskszsummary human2bytes
 		ipsort ipaddrval loadtype
@@ -99,7 +100,7 @@ our @EXPORT = qw($VERSION $devtype $script $lscript @modules $inloop
 		RunCommand sortbyipaddr valsort which);
 
 BEGIN {
-    $VERSION = '3.13';
+    $VERSION = '3.14';
 }
 
 # initialize common rancid parameters and handle command-line arguments.
@@ -107,7 +108,7 @@ sub rancidinit {
     my($i);
 
     if ($main::opt_V) {
-	print "rancid 3.13\n";
+	print "rancid 3.14\n";
 	exit(0);
     }
 
@@ -127,6 +128,7 @@ sub rancidinit {
     $timeo = $timeodef;			# login script timeout in seconds
 
     $aclsort = "ipsort";		# ACL sorting mode
+    $aclfilterregex = "";		# ACL filter regex
 
     # determine ACL sorting mode
     if (defined($ENV{"ACLSORT"}) && $ENV{"ACLSORT"} =~ /no/i) {
@@ -137,6 +139,11 @@ sub rancidinit {
     } else {
 	$aclfilterseq = "1";
     }
+    if (defined($ENV{"ACLFILTERREGEX"})) {
+	$aclfilterregex = $ENV{"ACLFILTERREGEX"};
+	# ACLFILTERSEQ is implied
+	$aclfilterseq = "1";
+    }
 
     # determine community string filtering mode
     if (defined($ENV{"NOCOMMSTR"}) && $ENV{"NOCOMMSTR"} =~ /yes/i) {
