@@ -1,7 +1,7 @@
 package sros;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.13;
+use rancid 3.14;
 
 our $proc;
 our $memoryseen;
@@ -139,35 +139,6 @@ CMD:	if (/[#]\s?logout\s*$/) {
     }
 }
 
-# This routine parses "file type bootlog.txt"
-sub BootLog {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In BootLog: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	next if (/^\s+\^$/);
-	return(-1) if (/error: invalid parameter/i);
-	return(-1) if (/minor: cli command not allowed for this user/i);
-        # if file doesn't exist, return 0
-        return(0) if (/minor: cli could not access file/i);
-
-	if (/total memory:\s+(\S+)\s+chassis type:\s+(\S+)\s+card type:\s+(\S+)/i) {
-	    next if ($memoryseen++);
-	    ProcessHistory("COMMENTS","keysort","A1",
-			   "#Total memory: $1\n");
-	    ProcessHistory("COMMENTS","keysort","B1",
-			   "#Chassis type: $2\n");
-	    ProcessHistory("COMMENTS","keysort","B2",
-			   "#Card type: $3\n");
-	}
-	/^chassis serial number is \'(.*)\'/i &&
-	    ProcessHistory("COMMENTS","keysort","B1",
-			   "#Chassis serial number: $1\n") && next;
-    }
-}
 # This routine parses "show bof"
 sub ShowBOF {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -182,7 +153,7 @@ sub ShowBOF {
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 	/^INFO: CLI #\d+: Switching to the .* engine/ && next;
 	/show bof/i && next;
 
@@ -190,9 +161,11 @@ sub ShowBOF {
 	ProcessHistory("BOF","","","# $_");
     }
 }
+
 # This routine parses "show card detail"
 sub ShowCardDetail {
     my($INPUT, $OUTPUT, $cmd) = @_;
+    my($snseen, $mcseen) = (0, 0);
     print STDERR "    In ShowCardDetail: $_" if ($debug);
     ProcessHistory("COMMENTS","keysort","E6","#\n# $_");
 
@@ -204,7 +177,7 @@ sub ShowCardDetail {
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 
 	# humanize free space
 	if (/^(\s+free space\s+:\s+)([0-9,]+\s+.*)/i) {
@@ -217,7 +190,23 @@ sub ShowCardDetail {
 
 	# temp varies in "show card detail"
 	next if (/^(\s+Temperature\s+:)\s+\d+C/);
-	next if (/^(Config file|BOF) last (saved|modified)\s+:/ && ($filter_osc >= 2));
+	next if (/^(Config file|BOF) last (saved|modified)\s+:/ &&
+		($filter_osc >= 2));
+
+	# hardware data for the output head
+	# first serial number seen should be that of the chassis
+	if (!$snseen && /^\s+serial number\s+:\s+(\w+)/i) {
+	    ProcessHistory("COMMENTS","keysort","B1",
+			   "#Chassis serial number: $1\n");
+	    $snseen++;
+	}
+	# first memory capity seen should be hte overall total
+	if (!$mcseen && /^\s+memory capacity\s+:\s+(.*)/i) {
+	    my($hb) = bytes2human(human2bytes($1));
+	    ProcessHistory("COMMENTS","keysort","A1",
+			   "#Total memory: $hb\n");
+	    $mcseen++;
+	}
 
 	# power data
 	if (/hardware resources .power-zone/i) {
@@ -233,6 +222,7 @@ sub ShowCardDetail {
 	ProcessHistory("COMMENTS","keysort","E6","# $_");
     }
 }
+
 # This routine parses "show card state"
 sub ShowCardState {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -247,12 +237,13 @@ sub ShowCardState {
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 
 	/[-=]+$/i && next;
 	ProcessHistory("COMMENTS","keysort","E5","# $_");
     }
 }
+
 # This routine parses "show chassis"
 sub ShowChassis {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -267,7 +258,7 @@ sub ShowChassis {
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 	/^$/i && next; # extra blank lines tr doesn't remove
 
 	/[-=]+$/i && next;
@@ -282,12 +273,14 @@ sub ShowChassis {
 	    next;
 	ProcessHistory("COMMENTS","keysort","E1","# $_");
     }
+    ProcessHistory("COMMENTS","keysort","E1","#\n");
 }
+
 # This routine parses "show chassis environment"
 sub ShowChassisEnv {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowChassisEnv: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E2","#\n# $_");
+    ProcessHistory("COMMENTS","keysort","E3","#\n# $_");
 
 TOP: while (<$INPUT>) {
 	tr/\015//d;
@@ -297,7 +290,7 @@ TOP: while (<$INPUT>) {
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 
 	# power data
 	if (/hardware resources .power-zone/i) {
@@ -311,14 +304,15 @@ TOP: while (<$INPUT>) {
 	/speed/i && next;
 
 	/[-=]+$/i && next;
-	ProcessHistory("COMMENTS","keysort","E2","# $_");
+	ProcessHistory("COMMENTS","keysort","E3","# $_");
     }
 }
+
 # This routine parses "show chassis power-supply"
 sub ShowChassisPS {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowChassisPS: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E3","#\n# $_");
+    ProcessHistory("COMMENTS","keysort","E4","#\n# $_");
 
     while (<$INPUT>) {
 	tr/\015//d;
@@ -330,17 +324,19 @@ sub ShowChassisPS {
 	return(0) if (/minor: .* unknown element/i);    # cmd for 7750 SR only
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 
 	/[-=]+$/i && next;
-	ProcessHistory("COMMENTS","keysort","E3","# $_");
+	/input voltage/i && next;
+	ProcessHistory("COMMENTS","keysort","E4","# $_");
     }
 }
+
 # This routine parses "show chassis power-management"
 sub ShowChassisPM {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowChassisPM: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E4","#\n# $_");
+    ProcessHistory("COMMENTS","keysort","E5","#\n# $_");
 
     while (<$INPUT>) {
 	tr/\015//d;
@@ -352,15 +348,16 @@ sub ShowChassisPM {
 	return(0) if (/minor: .* unknown element/i);    # cmd for 7950 XRS only
 	return(-1) if (/minor: cli command not allowed for this user/i);
         # context lines
-        /^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 
 	/volts/i && next;
 	/watts/i && next;
 	/amps/i && next;
 	/[-=]+$/i && next;
-	ProcessHistory("COMMENTS","keysort","E4","# $_");
+	ProcessHistory("COMMENTS","keysort","E5","# $_");
     }
 }
+
 # This routine parses "show debug"
 sub ShowDebug {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -375,13 +372,92 @@ sub ShowDebug {
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 	/^INFO: CLI #\d+: Switching to the .* engine/ && next;
 	/show debug/i && next;
 
 	ProcessHistory("","","","$_");
     }
 }
+
+# This routine parses "show mda detail"
+sub ShowMDA {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    print STDERR "    In ShowMDA: $_" if ($debug);
+    ProcessHistory("COMMENTS","keysort","E2","# $_");
+
+TOP: while (<$INPUT>) {
+	tr/\015//d;
+	last if (/^$prompt/);
+	next if (/^(\s*$cmd\s*)$/);
+	next if (/^\s+\^$/);
+	return(-1) if (/error: invalid parameter/i);
+	return(-1) if (/minor: cli command not allowed for this user/i);
+	# context lines
+	/^\[[^]]*]$/i && next;
+	/^$/i && next; # extra blank lines tr doesn't remove
+
+	/[-=]+$/i && next;
+	/Temperature/i && next;
+
+	# trim power info
+	# Hardware Resources (Power-Zone 1)
+	#     Voltage
+	#         Minimum                   :    54.88 Volts  (06/23/2022 15:53:39)
+	#         Current                   :    54.91 Volts 
+	#         Peak                      :    54.95 Volts  (04/28/2022 16:28:34)
+	#     Wattage
+	#         ....
+	#         Max Required              :  2400.00 Watts 
+	#     Amperage
+	#         ....
+	if (/hardware resources .power-zone/i) {
+	    while (<$INPUT>) {
+		tr/\015//d;
+		last TOP if (/^$prompt/);
+		last if (/(^\s*$|^=+)/);
+	    }
+	}
+
+	ProcessHistory("COMMENTS","keysort","E2","# $_");
+    }
+}
+
+# This routine parses "show port detail"
+sub ShowPortDetail {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    my($text);
+    print STDERR "    In ShowPortDetail: $_" if ($debug);
+    ProcessHistory("COMMENTS","keysort","E6","#\n# $_");
+
+TOP: while (<$INPUT>) {
+	tr/\015//d;
+	last if (/^$prompt/);
+	next if (/^(\s*|\s*$cmd\s*)$/);
+	next if (/^\s+\^$/);
+	return(-1) if (/error: invalid parameter/i);
+	return(-1) if (/minor: cli command not allowed for this user/i);
+	# context lines
+	/^\[[^]]*]$/i && next;
+
+	# accumulate interface name and description; only print if it has a xcvr
+	/^(Interface\s+:\s+\S+)/ && ($text = "# $1\n" . $text);
+	/^(Description\s+:\s+)/ && ($text = "# $_");
+	if (/^transceiver status\s*:\s*/i) {
+	    next TOP if (/not-equipped/);
+	    ProcessHistory("COMMENTS","keysort","E8","$text");
+	    while (<$INPUT>) {
+		tr/\015//d;
+		last TOP if (/^$prompt/);
+		last if (/(^\s*$|^[-=]+)/);
+		ProcessHistory("COMMENTS","keysort","E8","# $_");
+	    }
+	}
+
+	/[-=]+$/i && next;
+    }
+}
+
 # This routine parses "show redundancy synchronization"
 sub ShowRedundancy {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -398,7 +474,7 @@ sub ShowRedundancy {
 	return(0) if (/minor: .* synchronization is only supported/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 
 	/[-=]+$/i && next;
 	/standby up time/i && next;
@@ -410,6 +486,7 @@ sub ShowRedundancy {
 	ProcessHistory("COMMENTS","keysort","D2","# $_");
     }
 }
+
 # This routine parses "show system information"
 sub ShowSystemInfo {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -425,7 +502,7 @@ sub ShowSystemInfo {
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
 	# context lines
-	/^\[]$/i && next;
+	/^\[[^]]*]$/i && next;
 
 	/[-=]+$/i && next;
 	/system up time/i && next;
@@ -440,7 +517,7 @@ sub ShowSystemInfo {
 	if (/system type\s+:\s+(.*)/i) {
 	    $proc = $1;
 	    ProcessHistory("COMMENTS","keysort","B4",
-			   "#System type: $proc\n");
+			   "#Chassis type: $proc\n");
 	}
 	if (/system version\s+:\s+(.*)/i) {
 	    $proc = $1;
@@ -450,6 +527,7 @@ sub ShowSystemInfo {
 	ProcessHistory("COMMENTS","keysort","C1","# $_");
     }
 }
+
 # This routine parses "admin display-config index"
 sub WriteTermIndex {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -463,17 +541,20 @@ sub WriteTermIndex {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
+	# context lines
+	#/^\[[^]]*]$/i && next;
 
 	/# (timos-|all rights reserved|built on)/i && next;
-	/# Generated /i && next;
+	/# (Generated|Last modified|Last saved) /i && next;
 
 	/^#-+$/i && next;
 	s/echo \"(.*)\"/# $1/i;
 
-	next if (/^# finished \S{3} \S{3} /i);
+	next if (/^# finished /i);
 	ProcessHistory("","","","$_");
     }
 }
+
 # This routine parses "admin display-config"
 sub WriteTerm {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -487,9 +568,11 @@ sub WriteTerm {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
+	# context lines
+	#/^\[[^]]*]$/i && next;
 
 	/# (timos-|all rights reserved|built on)/i && next;
-	/# Generated /i && next;
+	/# (Generated|Last modified|Last saved) /i && next;
 
 	/^#-+$/i && next;
 	s/echo \"(.*)\"/# $1/i;
@@ -519,7 +602,7 @@ sub WriteTerm {
 	}
 
 	# end of config.
-	if (/^# finished \S{3} \S{3} /i) {
+	if (/^# finished /i) {
 	    $found_end = 1;
 	    return(0);
 	}
@@ -543,6 +626,8 @@ sub WriteTermMD {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
+	# context lines
+	#/^\[[^]]*]$/i && next;
 
 	/# (timos-|all rights reserved|built on)/i && next;
 	/# Generated /i && next;
@@ -575,9 +660,16 @@ sub WriteTermMD {
 		ProcessHistory("","","","$_") && next;
 	    }
 	}
+	if (/^(\s+authentication-key)\s+("\S+"\s+hash2)/) {
+	    if ($filter_pwds >= 1) {
+		ProcessHistory("","","","#$1 <removed>$'") && next;
+	    } else {
+		ProcessHistory("","","","$_") && next;
+	    }
+	}
 
 	# end of config.
-	if ((/^(# finished \S{3} \S{3} |\[\]\s*$)/i) && $linecnt > 5) {
+	if ((/^(# finished |\[\]\s*$)/i) && $linecnt > 5) {
 	    $found_end = 1;
 	    return(0);
 	}
