@@ -1,7 +1,7 @@
 package wavesvros;
 ##
-## rancid 3.13
-## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
+## rancid 3.14
+## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -54,9 +54,9 @@ use strict 'vars';
 use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
-$Exporter::Verbose=1;
+#$Exporter::Verbose=1;
 
-use rancid 3.13;
+use rancid 3.14;
 
 @ISA = qw(Exporter rancid main);
 #our @EXPORT = qw($VERSION)
@@ -187,7 +187,7 @@ sub ShowChassis {
 		tr/\015//d;
 		goto EndShowChassis if (/^$prompt/);
 		$PSW = 1 if (/power \(w\)/i);
-		if ($PSW && /^((?:\|[^|]+){7,})\|\s+(?:[0-9.]+ \|)/) {
+		if ($PSW && /^((?:\|[^|]+){6,7})\|\s+(?:[0-9.]+ \|)/) {
 		    ProcessHistory("","","","! $1|\n");
 		} else {
 		    ProcessHistory("","","","! $_");
